@@ -190,6 +190,7 @@ class _DAVResource(ABC):
     #        """
     #        raise NotImplementedError
 
+    @abstractmethod
     def get_content_length(self) -> Optional[int]:
         """Contains the Content-Length header returned by a GET without accept
         headers.
@@ -922,9 +923,9 @@ class _DAVResource(ABC):
     def end_write(self, *, with_errors):
         """Called when PUT has finished writing.
 
-        This is only a notification. that MAY be handled.
+        This is only a notification that MAY be handled.
         """
-        pass
+        return None
 
     def handle_delete(self):
         """Handle a DELETE request natively.
@@ -1182,7 +1183,7 @@ class _DAVResource(ABC):
         This gets called before the response is started.
         It enables adding additional headers or modifying the default ones.
         """
-        pass
+        return None
 
 
 # ========================================================================
@@ -1491,7 +1492,7 @@ class DAVProvider(ABC):
         self._count_get_resource_inst = 0
         self._count_get_resource_inst_init = 0
 
-    #        self.caseSensitiveUrls = True
+        # self.caseSensitiveUrls = True
 
     def __repr__(self):
         return self.__class__.__name__
@@ -1504,7 +1505,9 @@ class DAVProvider(ABC):
 
         This is the value of SCRIPT_NAME, when WsgiDAVApp is called.
         """
-        assert mount_path in ("", "/") or not mount_path.endswith("/")
+        assert mount_path in ("", "/") or (
+            mount_path.startswith("/") and not mount_path.endswith("/")
+        )
         self.mount_path = mount_path
 
     def set_share_path(self, share_path):
