@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# (c) 2009-2022 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 """
 Implements a property manager based on CouchDB.
@@ -22,13 +22,12 @@ Valid options are (sample shows defaults)::
             }
 
 """
-from __future__ import print_function
-
+from urllib.parse import quote
 from uuid import uuid4
 
 import couchdb
 
-from wsgidav import compat, util
+from wsgidav import util
 
 __docformat__ = "reStructuredText"
 
@@ -39,7 +38,7 @@ _logger = util.get_module_logger(__name__)
 # ============================================================================
 
 
-class CouchPropertyManager(object):
+class CouchPropertyManager:
     """Implements a property manager based on CouchDB."""
 
     def __init__(self, options):
@@ -178,7 +177,7 @@ class CouchPropertyManager(object):
             doc = {
                 "_id": uuid4().hex,  # Documentation suggests to set the id
                 "url": norm_url,
-                "title": compat.quote(norm_url),
+                "title": quote(norm_url),
                 "type": "properties",
                 "properties": {name: property_value},
             }
@@ -215,7 +214,7 @@ class CouchPropertyManager(object):
         doc2 = {
             "_id": uuid4().hex,
             "url": destUrl,
-            "title": compat.quote(destUrl),
+            "title": quote(destUrl),
             "type": "properties",
             "properties": doc["properties"],
         }
