@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# (c) 2009-2022 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 """
 Simple example how to a run WsgiDAV in a 3rd-party WSGI server.
 """
-from __future__ import print_function
-
 from tempfile import gettempdir
 
 from wsgidav import __version__
@@ -27,9 +25,11 @@ def main():
         },
         "simple_dc": {"user_mapping": {"*": True}},  # anonymous access
         "verbose": 1,
-        "enable_loggers": [],
+        "logging": {
+            "enable_loggers": [],
+        },
         "property_manager": True,  # True: use property_manager.PropertyManager
-        "lock_manager": True,  # True: use lock_manager.LockManager
+        "lock_storage": True,  # True: use LockManager(lock_storage.LockStorageDict)
     }
     app = WsgiDAVApp(config)
 
