@@ -1,16 +1,13 @@
 # -*- coding: utf-8 -*-
-# (c) 2009-2021 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
+# (c) 2009-2022 Martin Wendt and contributors; see WsgiDAV https://github.com/mar10/wsgidav
 # Original PyFileServer (c) 2005 Ho Chun Wei.
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/mit-license.php
 """
 Small wrapper for different etree packages.
 """
-# from __future__ import print_function
-
 import logging
-
-from wsgidav import compat
+from io import StringIO
 
 __docformat__ = "reStructuredText"
 
@@ -72,12 +69,15 @@ def string_to_xml(text):
         raise
 
 
-def xml_to_bytes(element, pretty_print=False):
+def xml_to_bytes(element, *, pretty=False):
     """Wrapper for etree.tostring, that takes care of unsupported pretty_print
     option and prepends an encoding header."""
     if use_lxml:
-        xml = etree.tostring(
-            element, encoding="UTF-8", xml_declaration=True, pretty_print=pretty_print
+        xml = etree.tostring(  # pylint: disable=unexpected-keyword-arg
+            element,
+            encoding="UTF-8",
+            xml_declaration=True,
+            pretty_print=pretty,
         )
     else:
         xml = etree.tostring(element, encoding="UTF-8")
@@ -95,14 +95,14 @@ def make_multistatus_el():
     return etree.Element("{DAV:}multistatus")
 
 
-def make_prop_el():
+def make_prop_elem():
     """Wrapper for etree.Element, that takes care of unsupported nsmap option."""
     if use_lxml:
         return etree.Element("{DAV:}prop", nsmap={"D": "DAV:"})
     return etree.Element("{DAV:}prop")
 
 
-def make_sub_element(parent, tag, nsmap=None):
+def make_sub_element(parent, tag, *, nsmap=None):
     """Wrapper for etree.SubElement, that takes care of unsupported nsmap option."""
     if use_lxml:
         return etree.SubElement(parent, tag, nsmap=nsmap)
@@ -118,10 +118,10 @@ def element_content_as_string(element):
     """
     if len(element) == 0:
         return element.text or ""  # Make sure, None is returned as ''
-    stream = compat.StringIO()
+    stream = StringIO()
     for childnode in element:
-        stream.write(xml_to_bytes(childnode, pretty_print=False) + "\n")
-        # print(xml_to_bytes(childnode, pretty_print=False), file=stream)
+        stream.write(xml_to_bytes(childnode, pretty=False) + "\n")
+        # print(xml_to_bytes(childnode, pretty=False), file=stream)
     s = stream.getvalue()
     stream.close()
     return s
